MixedStreamAudioConfig class

@brief Config for mixed stream (audio).

Properties

audioCodec → MixedStreamAudioCodecType
final
audioProfile → MixedStreamAudioProfile
final
bitrate → int
final
channels → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleRate → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited