MixedStreamLayoutRegionConfig class

@brief Layout information for a single image or video stream in the mixed stream. After enabling the push-to-CDN function, you can set the preset layout information for one of the video streams in the mixed stream.

Properties

alpha → double
@brief Layout region alpha
final
alternateImageFillMode → MixedStreamAlternateImageFillMode
@brief Image watermark fill mode
final
alternateImageUrl → String
@brief Placeholder image URL
final
applySpatialAudio → bool
@brief Apply spatial audio
final
cornerRadius → double
@brief Layout region corner radius
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
@brief Layout region height
final
imageWaterMark → Uint8List?
@brief Image watermark
final
imageWaterMarkConfig → MixedStreamLayoutRegionImageWaterMarkConfig?
@brief Image watermark config
final
isLocalUser → bool
@brief Is local user
final
locationX → int
@brief Layout region top-left x coordinate
final
locationY → int
@brief Layout region top-left y coordinate
final
mediaType → MixedStreamMediaType
@brief Layout region media type
final
regionContentType → MixedStreamLayoutRegionType
@brief Layout region content type
final
renderMode → MixedStreamRenderMode
@brief Layout region render mode
final
roomId → String
@brief Room ID
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceCrop → SourceCrop?
@brief Video source crop
final
spatialPosition → Position?
@brief Spatial audio position
final
streamType → MixedStreamVideoType
@brief Video stream type
final
userId → String
@brief User ID
final
width → int
@brief Layout region width
final
zOrder → int
@brief Layout region z-order
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited