MixedStreamSpatialAudioConfig class

@brief Spatial audio configuration

Properties

audienceSpatialOrientation → HumanOrientation?
@brief Audience spatial audio orientation
final
audienceSpatialPosition → Position?
@brief Audience spatial audio position
final
enableSpatialRender → bool
@brief Enable spatial audio
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited