RTCSurfaceView class

Video rendering settings.

If you are developing an Android application with Flutter 3.0.0 or above, it is recommended to use Android 6.0 or above devices, otherwise there will be layer display errors.

Different platforms correspond to different objects:

Inheritance

Properties

backgroundColor → int
@brief Background color for filling the blank part of the canvas
final
context → RTCViewContext
@brief Context for instance initialization
final
gestureRecognizers → Set<Factory<OneSequenceGestureRecognizer>>?
@brief Which gestures should be passed to PlatformView
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPlatformViewCreated → PlatformViewCreatedCallback?
@brief PlatformView is created when this callback is received
final
renderMode → VideoRenderMode
@brief Video rendering mode
final
renderRotation → VideoRotation
@brief Video rotation angle
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zOrderMediaOverlay → bool
@brief Set whether the Surface of SurfaceView is placed on top of another regular SurfaceView.
final
zOrderOnTop → bool
@brief Set whether the Surface of SurfaceView is placed on top of the window it is in.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited