LocalSnapshot class

@brief Local snapshot

Properties

filePath → String
@brief Snapshot result file path
final
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
@brief Image height
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskId ↔ int
@brief Snapshot task ID
getter/setter pair
width ↔ int
@brief Image width
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited