RTCVideoContext class

@brief Engine initialization parameters

Properties

appId ↔ String
@brief The unique identifier for each application, randomly generated by the RTC console.
getter/setter pair
autoCreateAudioEffectPlayer ↔ bool
@brief Whether to automatically create an audio effect manager
getter/setter pair
autoCreateVideoEffectInterface ↔ bool
@brief Whether to automatically create a video effect manager
getter/setter pair
autoCreateWTNStream ↔ bool
@brief Whether to automatically create a public stream interface
getter/setter pair
eventHandler ↔ IRTCEngineEventHandler?
@brief Engine related callback events
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isGameScene ↔ bool
@brief Whether it is a game scene type
getter/setter pair
parameters ↔ Map<String, dynamic>?
@brief Private parameters. Please contact technical support for use.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited