autoCreateVideoEffectInterface property
@brief Whether to automatically create a video effect manager
Implementation
bool autoCreateVideoEffectInterface;
@brief Whether to automatically create a video effect manager
bool autoCreateVideoEffectInterface;