EngineConfig class

Inheritance
  • Object
  • NativeClass
  • EngineConfig

Constructors

EngineConfig([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
appID ↔ FutureOr<String?>
@brief required. A unique identifier for each App, randomly generated by the RTC console. Engine instances created with different AppIds cannot communicate with each other.
getter/setter pair
context ↔ FutureOr<Context>
@brief 必填,Android Application Context
getter/setter pair
eglContext ↔ FutureOr<Object?>
@brief Optional. If you need SDK to support custom texture hardcoding, you must import the eglContext in a JObject
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isGameScene ↔ FutureOr<boolean?>
@brief game scene type.
getter/setter pair
nativeLoadPath ↔ FutureOr<String?>
@hidden for internal use only @brief Optional. so file loading address, if you need to dynamically load the plug-in library, you can set the dynamic library address through this field
getter/setter pair
parameters ↔ FutureOr<Context>
@brief Optional. Reserved parameters. Please contact technical support fellow if needed.
getter/setter pair
ready → Future<void>
Whether the instance is initialized
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter