ExpressionDetectInfo class

Inheritance
  • Object
  • NativeClass
  • ExpressionDetectInfo

Constructors

ExpressionDetectInfo([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
age ↔ FutureOr<float?>
@brief The estimated age in range of (0, 100).
getter/setter pair
angryScore ↔ FutureOr<float?>
@brief The estimated angry score in range of (0, 100).
getter/setter pair
arousal ↔ FutureOr<float?>
@brief The estimated emotional arousal in range of (0, 100).
getter/setter pair
attractive ↔ FutureOr<float?>
@brief The estimated attractiveness in range of (0, 100).
getter/setter pair
boyProb ↔ FutureOr<float?>
@brief The estimated probability of being a male in range of (0.0, 1.0).
getter/setter pair
happyScore ↔ FutureOr<float?>
@brief The estimated happy score in range of (0, 100).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ready → Future<void>
Whether the instance is initialized
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sadScore ↔ FutureOr<float?>
@brief The estimated sad score in range of (0, 100).
getter/setter pair
surpriseScore ↔ FutureOr<float?>
@brief The estimated surprise score in range of (0, 100).
getter/setter pair
valence ↔ FutureOr<float?>
@brief The estimated emotional valence in range of (-100, 100).
getter/setter pair

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter