LocalStreamStats class

Inheritance
  • Object
  • NativeClass
  • LocalStreamStats

Constructors

LocalStreamStats([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
audioStats ↔ FutureOr<LocalAudioStats?>
@brief For statistics on audio streams sent by local devices. See LocalAudioStats{@link #LocalAudioStats}.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isScreen ↔ FutureOr<boolean?>
@brief Whether the media stream belongs to the user is a screen stream. You can know whether the current statistics come from mainstream or screen stream.
getter/setter pair
ready → Future<void>
Whether the instance is initialized
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
rxQuality ↔ FutureOr<int?>
@brief Local media downlink network quality. See NetworkQuality{@link #NetworkQuality}. @deprecated since 3.45 and will be deleted in 3.51, use onNetworkQuality{@link #IRTCRoomEventHandler#onNetworkQuality} instead.
getter/setter pair
txQuality ↔ FutureOr<int?>
@brief For local media uplink network quality. See NetworkQuality{@link #NetworkQuality}. @deprecated since 3.45 and will be deleted in 3.51, use onNetworkQuality{@link #IRTCRoomEventHandler#onNetworkQuality} instead.
getter/setter pair
videoStats ↔ FutureOr<LocalVideoStats?>
@brief For statistics on video streams sent by local devices. See LocalVideoStats{@link #LocalVideoStats}.
getter/setter pair

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter