MixedStreamConfig class

Inheritance
  • Object
  • NativeClass
  • MixedStreamConfig

Constructors

MixedStreamConfig([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
advancedConfig ↔ FutureOr<Context>
@hidden for internal use only
getter/setter pair
audioConfig ↔ FutureOr<MixedStreamAudioConfig?>
@detail api @brief Sets audio transcoding configurations. It's recommended to be set. @param audioConfig The audio configurations to be set. See MixedStreamAudioConfig{@link #MixedStreamConfig-MixedStreamAudioConfig}.
getter/setter pair
authInfo ↔ FutureOr<Context>
@hidden for internal use only
getter/setter pair
backgroundColor ↔ FutureOr<String?>
@detail api @brief Sets the background color of the canvas. With invalid or empty input, the configurations will be set as the default values. @param backgroundColor Background-color of the mixed stream in hexadecimal values such as #FFFFFF and #000000. The default value is #000000 (black).
getter/setter pair
backgroundImageURL ↔ FutureOr<String?>
@valid since 3.57 @detail api @brief Sets the URL of the background image for the canvas that renders the mixed stream @param backgroundImageURL URL of the background image with a maximum length of 1023 bytes.
The URL must start with http, and you can input images in the following supported formats: JPG, JPEG, PNG.
If the width and height of the background image are different from the screen dimensions, the background image will be scaled to fill the screen.
getter/setter pair
controlConfig ↔ FutureOr<MixedStreamControlConfig?>
@valid since 3.56 @detail api @brief Sets the configurations during mixing streams on the server side. @param controlConfig The configurations to be set. See MixedStreamControlConfig{@link #MixedStreamConfig-MixedStreamControlConfig}.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
interpolationMode ↔ FutureOr<InterpolationMode?>
@detail api @brief Sets the interpolationMode mode of the WTN stream. See InterpolationMode{@link #InterpolationMode}.
getter/setter pair
layoutMode ↔ FutureOr<StreamLayoutMode?>
@detail api @brief Sets the layout mode of the WTN stream. See StreamLayoutMode{@link #StreamLayoutMode}.
getter/setter pair
ready → Future<void>
Whether the instance is initialized
no setterinherited
regions ↔ FutureOr<Array<MixedStreamLayoutRegionConfig>?>
@detail api @brief Sets the user layout information list. @param regions User layout information list. It's a list of MixedStreamLayoutRegionConfig{@link #MixedStreamConfig#MixedStreamLayoutRegionConfig} that you construct for each stream.
With invalid or empty input, the configurations will be set as the default values.
getter/setter pair
roomID ↔ FutureOr<String?>
@detail api @brief Set the room ID to specify where the streams to be mixed sources from. @param roomID The room ID @note This parameters cannot be updated during.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spatialAudioConfig ↔ FutureOr<MixedStreamSpatialAudioConfig?>
@detail api @brief Sets the spatial audio configuration when pushing streams to CDN. @param spatialConfig The configurations to be set. See MixedStreamSpatialAudioConfig{@link #MixedStreamConfig-MixedStreamSpatialAudioConfig}.
getter/setter pair
userConfigExtraInfo ↔ FutureOr<String?>
@detail api @brief set user config extra information. @param userConfigExtraInfo Extra information. @note This parameter is not supported for WTN stream tasks.
getter/setter pair
userID ↔ FutureOr<String?>
@detail api @brief Sets the user ID to specify who started the mixing-stream task. The sum length of roomID and userID should not exceed 126 bytes. It's recommended to be set.
This parameter cannot be updated during the. @param userID The user ID.
getter/setter pair
videoConfig ↔ FutureOr<MixedStreamVideoConfig?>
@detail api @brief Sets the video transcoding configurations. It's recommended to be set. @param videoConfig The configurations to be set. See MixedStreamVideoConfig{@link #MixedStreamConfig-MixedStreamVideoConfig}.
getter/setter pair

Methods

destroy() → void
inherited
getMixedStreamAdvancedConfig() → FutureOr<String>
@hidden constructor/destructor
getMixedStreamAudioConfigAudioProfile() → FutureOr<String>
@hidden constructor/destructor
getMixedStreamaudioConfigBitrate() → FutureOr<int>
@hidden constructor/destructor
getMixedStreamAudioConfigChannels() → FutureOr<int>
@hidden constructor/destructor
getMixedStreamAudioConfigCodec() → FutureOr<String>
@hidden constructor/destructor
getMixedStreamAudioConfigSampleRate() → FutureOr<int>
@hidden constructor/destructor
getMixedStreamAuthInfo() → FutureOr<String>
@hidden constructor/destructor
getMixedStreamBackgroundColor() → FutureOr<String>
@hidden constructor/destructor
getMixedStreamBackgroundImageURL() → FutureOr<String>
@hidden constructor/destructor
getMixedStreamInterpolationMode() → FutureOr<int>
@hidden constructor/destructor
getMixedStreamLayoutMode() → FutureOr<int>
@hidden constructor/destructor
getMixedStreamLayoutmode() → FutureOr<int>
@hidden constructor/destructor
getMixedStreamLayoutRegionAlpha(MixedStreamLayoutRegionConfig region) → FutureOr<float>
@hidden constructor/destructor
getMixedStreamLayoutRegionAlternateImageFillMode(MixedStreamLayoutRegionConfig region) → FutureOr<int>
@hidden constructor/destructor
getMixedStreamLayoutRegionAlternateImageURL(MixedStreamLayoutRegionConfig region) → FutureOr<String>
@hidden constructor/destructor
getMixedStreamLayoutRegionApplySpatialAudio(MixedStreamLayoutRegionConfig region) → FutureOr<boolean>
@hidden constructor/destructor
getMixedStreamLayoutRegionConfigs() → FutureOr<Array<MixedStreamLayoutRegionConfig>>
@hidden constructor/destructor
getMixedStreamLayoutRegionContentType(MixedStreamLayoutRegionConfig region) → FutureOr<int>
@hidden constructor/destructor
getMixedStreamLayoutRegionCornerRadius(MixedStreamLayoutRegionConfig region) → FutureOr<float>
@hidden constructor/destructor
getMixedStreamLayoutRegionData(MixedStreamLayoutRegionConfig region) → FutureOr<ArrayBuffer>
@hidden constructor/destructor
getMixedStreamLayoutRegionDataParamImageHeight(MixedStreamLayoutRegionConfig region) → FutureOr<int>
@hidden constructor/destructor
getMixedStreamLayoutRegionDataParamImageWidth(MixedStreamLayoutRegionConfig region) → FutureOr<int>
@hidden constructor/destructor
getMixedStreamLayoutRegionH(MixedStreamLayoutRegionConfig region) → FutureOr<int>
@hidden constructor/destructor
getMixedStreamLayoutRegionLocalUser(MixedStreamLayoutRegionConfig region) → FutureOr<boolean>
@hidden constructor/destructor
getMixedStreamLayoutRegionMediaType(MixedStreamLayoutRegionConfig region) → FutureOr<int>
@hidden constructor/destructor
getMixedStreamLayoutRegionRenderMode(MixedStreamLayoutRegionConfig region) → FutureOr<int>
@hidden constructor/destructor
getMixedStreamLayoutRegionRoomID(MixedStreamLayoutRegionConfig region) → FutureOr<String>
@hidden constructor/destructor
getMixedStreamLayoutRegionScreenStream(MixedStreamLayoutRegionConfig region) → FutureOr<int>
@hidden constructor/destructor
getMixedStreamLayoutRegionSpatialPositionX(MixedStreamLayoutRegionConfig region) → FutureOr<float>
@hidden constructor/destructor
getMixedStreamLayoutRegionSpatialPositionY(MixedStreamLayoutRegionConfig region) → FutureOr<float>
@hidden constructor/destructor
getMixedStreamLayoutRegionSpatialPositionZ(MixedStreamLayoutRegionConfig region) → FutureOr<float>
@hidden constructor/destructor
getMixedStreamLayoutRegionUserID(MixedStreamLayoutRegionConfig region) → FutureOr<String>
@hidden constructor/destructor
getMixedStreamLayoutRegionW(MixedStreamLayoutRegionConfig region) → FutureOr<int>
@hidden constructor/destructor
getMixedStreamLayoutRegionX(MixedStreamLayoutRegionConfig region) → FutureOr<int>
@hidden constructor/destructor
getMixedStreamLayoutRegionY(MixedStreamLayoutRegionConfig region) → FutureOr<int>
@hidden constructor/destructor
getMixedStreamLayoutRegionZOrder(MixedStreamLayoutRegionConfig region) → FutureOr<int>
@hidden constructor/destructor
getMixedStreamLayoutSourceCropH(MixedStreamLayoutRegionConfig region) → FutureOr<float>
@hidden constructor/destructor
getMixedStreamLayoutSourceCropW(MixedStreamLayoutRegionConfig region) → FutureOr<float>
@hidden constructor/destructor
getMixedStreamLayoutSourceCropX(MixedStreamLayoutRegionConfig region) → FutureOr<float>
@hidden constructor/destructor
getMixedStreamLayoutSourceCropY(MixedStreamLayoutRegionConfig region) → FutureOr<float>
@hidden constructor/destructor
getMixedStreamRoomID() → FutureOr<String>
@hidden constructor/destructor
getMixedStreamServerControlConfigEnableVolumeIndication() → FutureOr<boolean>
@hidden constructor/destructor
getMixedStreamServerControlConfigIsAddVolumeValue() → FutureOr<boolean>
@hidden constructor/destructor
getMixedStreamServerControlConfigMediaType() → FutureOr<int>
@hidden constructor/destructor
getMixedStreamServerControlConfigPushStreamMode() → FutureOr<int>
@hidden constructor/destructor
getMixedStreamServerControlConfigSeiContentMode() → FutureOr<int>
@hidden constructor/destructor
getMixedStreamServerControlConfigSeiPayloadType() → FutureOr<int>
@hidden constructor/destructor
getMixedStreamServerControlConfigSeiPayloadUuid() → FutureOr<String>
@hidden constructor/destructor
getMixedStreamServerControlConfigTalkVolume() → FutureOr<int>
@hidden constructor/destructor
getMixedStreamServerControlConfigVolumeIndicationInterval() → FutureOr<float>
@hidden constructor/destructor
getMixedStreamSpatialConfigAudienceSpatialOrientationForwardX() → FutureOr<float>
@hidden constructor/destructor
getMixedStreamSpatialConfigAudienceSpatialOrientationForwardY() → FutureOr<float>
@hidden constructor/destructor
getMixedStreamSpatialConfigAudienceSpatialOrientationForwardZ() → FutureOr<float>
@hidden constructor/destructor
getMixedStreamSpatialConfigAudienceSpatialOrientationRightX() → FutureOr<float>
@hidden constructor/destructor
getMixedStreamSpatialConfigAudienceSpatialOrientationRightY() → FutureOr<float>
@hidden constructor/destructor
getMixedStreamSpatialConfigAudienceSpatialOrientationRightZ() → FutureOr<float>
@hidden constructor/destructor
getMixedStreamSpatialConfigAudienceSpatialOrientationUpX() → FutureOr<float>
@hidden constructor/destructor
getMixedStreamSpatialConfigAudienceSpatialOrientationUpY() → FutureOr<float>
@hidden constructor/destructor
getMixedStreamSpatialConfigAudienceSpatialOrientationUpZ() → FutureOr<float>
@hidden constructor/destructor
getMixedStreamSpatialConfigAudienceSpatialPositionX() → FutureOr<float>
@hidden constructor/destructor
getMixedStreamSpatialConfigAudienceSpatialPositionY() → FutureOr<float>
@hidden constructor/destructor
getMixedStreamSpatialConfigAudienceSpatialPositionZ() → FutureOr<float>
@hidden constructor/destructor
getMixedStreamSpatialConfigEnableSpatialRender() → FutureOr<boolean>
@hidden constructor/destructor
getMixedStreamSyncControlConfigBaseUser() → FutureOr<String>
@hidden constructor/destructor
getMixedStreamSyncControlConfigQueueLength() → FutureOr<int>
@hidden constructor/destructor
getMixedStreamSyncControlConfigSyncStrategy() → FutureOr<int>
@hidden constructor/destructor
getMixedStreamSyncControlConfigVideoNeedMix() → FutureOr<boolean>
@hidden constructor/destructor
getMixedStreamUserConfigExtraInfo() → FutureOr<String>
@hidden constructor/destructor
getMixedStreamUserID() → FutureOr<String>
@hidden constructor/destructor
getMixedStreamVideoConfigBFrame() → FutureOr<boolean>
getMixedStreamVideoConfigBitrate() → FutureOr<int>
@hidden constructor/destructor
getMixedStreamVideoConfigCodec() → FutureOr<String>
@hidden constructor/destructor
getMixedStreamVideoConfigFps() → FutureOr<int>
@hidden constructor/destructor
getMixedStreamVideoConfigGop() → FutureOr<int>
@hidden constructor/destructor
getMixedStreamVideoConfigHeight() → FutureOr<int>
@hidden constructor/destructor
getMixedStreamVideoConfigWidth() → FutureOr<int>
@hidden constructor/destructor
getTranscodeMessage() → FutureOr<Context>
@hidden constructor/destructor
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter