MixedStreamPushTargetConfig class

Inheritance
  • Object
  • NativeClass
  • MixedStreamPushTargetConfig

Constructors

MixedStreamPushTargetConfig([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
pushCDNURL ↔ FutureOr<String?>
@detail api @brief Sets the URL for the mixed stream to be pushed to. Only supports live transcoding via RTMP. The URL should match the regular expression /^rtmps?:\\/\\//. It's recommended to be set.
This parameter cannot be updated while pushing stream to the CDN.
getter/setter pair
pushTargetType ↔ FutureOr<MixedStreamPushTargetType?>
@detail api @brief The push task type.
getter/setter pair
pushWTNStreamID ↔ FutureOr<String?>
@detail keytype @brief The WTN stream ID.This parameter is not supported for mixing-stream stream tasks.
getter/setter pair
ready → Future<void>
Whether the instance is initialized
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() → void
inherited
getMixedStreamPushTargetTypePushCDNURL() → FutureOr<String>
getMixedStreamPushTargetTypePushTargetType() → FutureOr<int>
getMixedStreamPushTargetTypePushWTNStreamID() → FutureOr<String>
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter