MixedStreamVideoConfig class

Inheritance
  • Object
  • NativeClass
  • MixedStreamVideoConfig

Constructors

MixedStreamVideoConfig([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
bitrate ↔ FutureOr<int?>
@hidden constructor/destructor
getter/setter pair
enableBframe ↔ FutureOr<boolean?>
@hidden constructor/destructor
getter/setter pair
fps ↔ FutureOr<int?>
@hidden constructor/destructor
getter/setter pair
gop ↔ FutureOr<int?>
@hidden constructor/destructor
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ FutureOr<int?>
@hidden constructor/destructor
getter/setter pair
ready → Future<void>
Whether the instance is initialized
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
videoCodec ↔ FutureOr<MixedStreamVideoCodecType?>
@hidden constructor/destructor
getter/setter pair
width ↔ FutureOr<int?>
@hidden constructor/destructor
getter/setter pair

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter