ProblemFeedbackInfo class

Inheritance
  • Object
  • NativeClass
  • ProblemFeedbackInfo

Constructors

ProblemFeedbackInfo([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
problemDesc ↔ FutureOr<String?>
@brief Text description
getter/setter pair
ready → Future<void>
Whether the instance is initialized
no setterinherited
roomInfo ↔ FutureOr<List<ProblemFeedbackRoomInfo>?>
@brief Room info. See ProblemFeedbackRoomInfo{@link #ProblemFeedbackRoomInfo}.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() → void
inherited
getProblemDesc() → FutureOr<String>
@hidden
getRoomInfo() → FutureOr<Array<ProblemFeedbackRoomInfo>>
@hidden
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter