RTCEncodedVideoFrame class

Inheritance
  • Object
  • NativeClass
  • RTCEncodedVideoFrame

Constructors

RTCEncodedVideoFrame([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
buffer ↔ FutureOr<ByteBuffer?>
@brief The pointer to the video frame
The buffer must be Direct. And the buffer size is its capacity.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ FutureOr<int?>
@brief Height of the video in px
getter/setter pair
ready → Future<void>
Whether the instance is initialized
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestampDtsUs ↔ FutureOr<int?>
@brief Video encoding timestamp in microseconds
getter/setter pair
timestampUs ↔ FutureOr<int?>
@brief Video capture timestamp in microseconds
getter/setter pair
videoCodecType ↔ FutureOr<VideoCodecType?>
@brief Video encoding type. See VideoCodecType{@link #VideoCodecType-2}
getter/setter pair
videoPictureType ↔ FutureOr<VideoPictureType?>
@brief Video compression picture type. See VideoPictureType{@link #VideoPictureType}
getter/setter pair
videoRotation ↔ FutureOr<VideoRotation?>
@brief Video frame rotation angle, the default value is 0 degrees. See VideoRotation{@link #VideoRotation}
getter/setter pair
width ↔ FutureOr<int?>
@brief Width of the video in px
getter/setter pair

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter