RTCRoomStats class

Inheritance
  • Object
  • NativeClass
  • RTCRoomStats

Constructors

RTCRoomStats([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
cpuAppUsage ↔ FutureOr<float?>
@brief CPU usage (%) of the application
getter/setter pair
cpuTotalUsage ↔ FutureOr<float?>
@brief Current CPU usage (%)
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ready → Future<void>
Whether the instance is initialized
no setterinherited
rtt ↔ FutureOr<int?>
@brief Round-trip time (in ms) from client side to server side
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
rxAudioKBitRate ↔ FutureOr<int?>
@brief The instantaneous value of audio Rx bitrate in kbps
getter/setter pair
rxBytes ↔ FutureOr<int?>
@brief Cumulative data received by the user in bytes.
getter/setter pair
rxCellularKBitrate ↔ FutureOr<int?>
@brief Rx cellular bandwidth consumption
getter/setter pair
rxJitter ↔ FutureOr<int?>
@hidden currently not available @brief Rx jitter(ms)
getter/setter pair
rxKBitRate ↔ FutureOr<int?>
@brief The instantaneous value of Rx bitrate in kbps
getter/setter pair
rxLostrate ↔ FutureOr<float?>
@brief Current Rx packet loss rate. The range is 0,1.
getter/setter pair
rxScreenKBitRate ↔ FutureOr<int?>
@brief The instantaneous TX bitrate of screen-sharing video in Kbps
getter/setter pair
rxVideoKBitRate ↔ FutureOr<int?>
@brief The instantaneous value of video Rx bitrate in kbps
getter/setter pair
totalDuration ↔ FutureOr<int?>
@brief The duration, in seconds, that the local user has spent in the room.
getter/setter pair
txAudioKBitRate ↔ FutureOr<int?>
@brief The instantaneous value of audio Tx bitrate in kbps
getter/setter pair
txBytes ↔ FutureOr<int?>
@brief Cumulative data sent by the user in bytes.
getter/setter pair
txCellularKBitrate ↔ FutureOr<int?>
@brief Tx cellular bandwidth consumption
getter/setter pair
txJitter ↔ FutureOr<int?>
@hidden currently not available @brief Tx jitter(ms)
getter/setter pair
txKBitRate ↔ FutureOr<int?>
@brief The instantaneous value of Tx bitrate in kbps
getter/setter pair
txLostrate ↔ FutureOr<float?>
@brief Current Tx packet loss rate. The range is 0,1.
getter/setter pair
txScreenKBitRate ↔ FutureOr<int?>
@brief The instantaneous RX bitrate of screen-sharing video in Kbps
getter/setter pair
txVideoKBitRate ↔ FutureOr<int?>
@brief The instantaneous value of video Tx bitrate in kbps
getter/setter pair
users ↔ FutureOr<int?>
@brief Number of visible users in the current room
getter/setter pair

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → FutureOr<void>
@detail api @brief Reset RTCRoomStats{@link #RTCRoomStats}
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter