RemoteStreamKey class

Inheritance
  • Object
  • NativeClass
  • RemoteStreamKey

Constructors

RemoteStreamKey([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
ready → Future<void>
Whether the instance is initialized
no setterinherited
roomId ↔ FutureOr<String?>
@brief The ID of the room from which the stream was published.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamIndex ↔ FutureOr<StreamIndex?>
@brief Stream type, see StreamIndex.
getter/setter pair
userId ↔ FutureOr<String?>
@brief The ID of the user who published the stream.
getter/setter pair

Methods

destroy() → void
inherited
getRoomId() → FutureOr<String>
@brief Gets the room ID
getStreamIndex() → FutureOr<StreamIndex>
@brief Gets stream type, see StreamIndex
getUserId() → FutureOr<String>
@brief Gets the user ID
hasNullProperty() → FutureOr<boolean>
@brief Check the class has null property
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter