RemoteVideoSinkConfig class

Inheritance
  • Object
  • NativeClass
  • RemoteVideoSinkConfig

Constructors

RemoteVideoSinkConfig([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
applyRotation ↔ FutureOr<VideoApplyRotation?>
@brief Whether the video frame needs to be automatically rotate. See VideoApplyRotation{@link #VideoApplyRotation}. The default value is no rotate.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mirrorType ↔ FutureOr<VideoSinkMirrorType?>
@brief Whether the video frame needs to be mirrored. See VideoSinkMirrorType{@link #VideoSinkMirrorType}. The default value is no mirroring effect.
getter/setter pair
pixelFormat ↔ FutureOr<VideoPixelFormat?>
@brief The pixel format of the remote video frame. See VideoPixelFormat{@link #VideoPixelFormat}. The default value is 0.
getter/setter pair
position ↔ FutureOr<RemoteVideoSinkPosition?>
@brief The position of the remote video frame. See RemoteVideoSinkPosition{@link #RemoteVideoSinkPosition}. The default position is after processing.
getter/setter pair
ready → Future<void>
Whether the instance is initialized
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter