SubtitleMessage class

Inheritance
  • Object
  • NativeClass
  • SubtitleMessage

Constructors

SubtitleMessage([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
definite ↔ FutureOr<boolean?>
@brief Whether transcribed texts are complete sentences. True means yes and False means no.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
language ↔ FutureOr<String?>
@brief The language of the transcribed or translated text according to the subtitle mode.
getter/setter pair
mode ↔ FutureOr<SubtitleMode?>
@brief Subtitle mode. Refer to SubtitleMode{@link #SubtitleMode} for more details.
getter/setter pair
ready → Future<void>
Whether the instance is initialized
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence ↔ FutureOr<int?>
@brief Incremental sequence numbers of the piece of the subtitle. Complete and incomplete sentences are numbered individually.
getter/setter pair
text ↔ FutureOr<String?>
@brief Subtitles encoded in UTF-8 format.
getter/setter pair
userId ↔ FutureOr<String?>
@brief The speaker's ID.
getter/setter pair

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter

Static Methods

create(String userId, String text, String language, int mode, int sequence, boolean definite) → FutureOr<SubtitleMessage>