VideoCaptureConfig class

Inheritance
  • Object
  • NativeClass
  • VideoCaptureConfig

Constructors

VideoCaptureConfig([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
capturePreference ↔ FutureOr<CapturePreference?>
@brief Video capture preference. See CapturePreference{@link #VideoCaptureConfig#CapturePreference}.
getter/setter pair
frameRate ↔ FutureOr<int?>
@brief Video capture frame rate in fps.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ FutureOr<int?>
@brief The height of video capture resolution in px.
getter/setter pair
ready → Future<void>
Whether the instance is initialized
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ FutureOr<int?>
@brief The width of video capture resolution in px.
getter/setter pair

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter