VideoFrameData class

Inheritance
  • Object
  • NativeClass
  • VideoFrameData

Constructors

VideoFrameData([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
bufferType ↔ FutureOr<VideoBufferType?>
@brief Video frame buffer type, see VideoBufferType{@link #VideoBufferType}. Required.
getter/setter pair
contentType ↔ FutureOr<VideoContentType?>
@brief Video content type. See VideoContentType{@link #VideoContentType}.
getter/setter pair
eglContext ↔ FutureOr<Context>
@brief EGLContext
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ FutureOr<int?>
@brief Video frame height. Required.
getter/setter pair
numberOfPlanes ↔ FutureOr<int?>
@brief The number of video frame plane. Required, when bufferType is RAW_MEMORY.
getter/setter pair
pixelFormat ↔ FutureOr<VideoPixelFormat?>
@brief Video frame pixel format, see VideoPixelFormat{@link #VideoPixelFormat}. Required, when bufferType is RAW_MEMORY or GL_TEXTURE.
getter/setter pair
planeData ↔ FutureOr<Array<ByteBuffer>?>
@brief Array of video frame plane. Required, when bufferType is RAW_MEMORY.
getter/setter pair
planeStride ↔ FutureOr<Array<int>?>
@brief Array of stride. Stride is the length of memory between two lines of image data in video frame plane in bytes. Required, when bufferType is RAW_MEMORY.
getter/setter pair
ready → Future<void>
Whether the instance is initialized
no setterinherited
roiData ↔ FutureOr<ArrayBuffer?>
@brief ROI(Region of Interest) Data in a video frame
getter/setter pair
rotation ↔ FutureOr<VideoRotation?>
@brief Video frame rotation angle
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seiData ↔ FutureOr<ArrayBuffer?>
@brief SEI data
getter/setter pair
textureId ↔ FutureOr<int?>
@brief Texture ID. Required, when bufferType is RAW_MEMORY or GL_TEXTURE.
getter/setter pair
textureMatrix ↔ FutureOr<Array<float>?>
@brief Texture matrix
getter/setter pair
timestampUs ↔ FutureOr<int?>
@brief Video frame timestamp in microseconds. Required.
getter/setter pair
width ↔ FutureOr<int?>
@brief Video frame width. Required.
getter/setter pair

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter