VideoFrameInfo class

Inheritance
  • Object
  • NativeClass
  • VideoFrameInfo

Constructors

VideoFrameInfo([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
height ↔ FutureOr<int?>
@brief High (pixels)
getter/setter pair
ready → Future<void>
Whether the instance is initialized
no setterinherited
rotation ↔ FutureOr<VideoRotation?>
@brief Video frame clockwise rotation angle. See VideoRotation{@link #VideoRotation}.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ FutureOr<int?>
@brief Width (pixels)
getter/setter pair

Methods

destroy() → void
inherited
getHeight() → FutureOr<int>
@hidden constructor/destructor
getWidth() → FutureOr<int>
@hidden constructor/destructor
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
setWidth(int width) → FutureOr<void>
@hidden constructor/destructor
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter