ByteRTCDeviceCollection class

Inheritance
  • Object
  • NativeClass
  • ByteRTCDeviceCollection

Constructors

ByteRTCDeviceCollection([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
ready → Future<void>
Whether the instance is initialized
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() → void
inherited
getCount() → FutureOr<int>
@detail api @author dixing @brief Get the number of media devices @return Number of media devices
getDevice(int index, NSString deviceName, NSString deviceID) → FutureOr<int>
@detail api @author dixing @brief Get the information of the specific device @param index Device index number, starting from 0. The index must be less than the return value of getCount{@link #ByteRTCDeviceCollection#getCount}. @param deviceName device name @param deviceID device ID @return - 0: Success. - !0: failure
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter