ByteRtcScreenCapturerExtDelegate class

Inheritance
  • Object
  • NativeClass
  • NativeObserverClass
  • ByteRtcScreenCapturerExtDelegate

Constructors

ByteRtcScreenCapturerExtDelegate([NativeClassOptions? options])

Properties

$instance ↔ dynamic
getter/setter pairinherited
$resource → NativeResource
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
ready → Future<void>
Whether the instance is initialized
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() → void
inherited
emit(String name, List args) → dynamic
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onNotifyAppRunning() → FutureOr<void>
@detail api @brief This callback is triggered when the App is detected to be making an audio/video call.
onQuitFromApp() → FutureOr<void>
@detail api @brief Notify Broadcast Upload Extension to stop capturing and exit. @note After the user calls stopScreenCapture{@link #ByteRTCEngine#stopScreenCapture} on iOS or stopScreenVideoCapture{@link #ByteRTCEngine#stopScreenVideoCapture} on macOS, this method will be triggered to notify the SDK on the Extension side to stop the screen capture.
onReceiveMessageFromApp(NSData message) → FutureOr<void>
@detail api @brief The callback is triggered when the socket receives a message from the App side @param message Message received from the App side
onSocketConnect() → FutureOr<void>
@detail api @brief This callback is triggered when the socket is successfully connected
onSocketDisconnect() → FutureOr<void>
@detail api @brief This callback is triggered when the socket is disconnected
registerEvent(String name, dynamic method) → void
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateInstance(dynamic instance) → void
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited