ByteRTCEncodedAudioFrameData class

Inheritance
  • Object
  • NativeClass
  • ByteRTCEncodedAudioFrameData

Constructors

ByteRTCEncodedAudioFrameData([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
buffer ↔ FutureOr<NSData?>
@hidden for internal use only @brief data
getter/setter pair
channel ↔ FutureOr<ByteRTCAudioChannel?>
@hidden for internal use only @brief Audio channel. See ByteRTCAudioChannel{@link #ByteRTCAudioChannel}.
For dual channels, the audio frames are interleaved.
getter/setter pair
codecType ↔ FutureOr<ByteRTCAudioCodecType?>
@hidden for internal use only @brief Audio encoding type. See ByteRTCAudioCodecType{@link #ByteRTCAudioCodecType}.
getter/setter pair
extraInfo ↔ FutureOr<NSData?>
@hidden for internal use only @brief extra info data
getter/setter pair
frameSizeMs ↔ FutureOr<int?>
@hidden for internal use only @brief Audio frame duration, unit: milliseconds
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ready → Future<void>
Whether the instance is initialized
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleRate ↔ FutureOr<ByteRTCAudioSampleRate?>
@hidden for internal use only @brief Sample rate. See ByteRTCAudioSampleRate{@link #ByteRTCAudioSampleRate}.
getter/setter pair
size ↔ FutureOr<int?>
@hidden for internal use only @brief data size
getter/setter pair
timestampUs ↔ FutureOr<int?>
@hidden for internal use only @brief Timestamp in microseconds.
getter/setter pair

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter