ByteRTCEncodedVideoFrame class

Inheritance
  • Object
  • NativeClass
  • ByteRTCEncodedVideoFrame

Constructors

ByteRTCEncodedVideoFrame([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
codecType ↔ FutureOr<ByteRTCVideoCodecType?>
@brief Video encoding type. See ByteRTCVideoCodecType{@link #ByteRTCVideoCodecType}
getter/setter pair
data ↔ FutureOr<NSData?>
@brief The pointer to the video frame
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ FutureOr<int?>
@brief Video frame height in px
getter/setter pair
pictureType ↔ FutureOr<ByteRTCVideoPictureType?>
@brief Encoded type of video frame. See ByteRTCVideoPictureType{@link #ByteRTCVideoPictureType}
getter/setter pair
ready → Future<void>
Whether the instance is initialized
no setterinherited
rotation ↔ FutureOr<ByteRTCVideoRotation?>
@brief Video frame rotation angle. See ByteRTCVideoRotation{@link #ByteRTCVideoRotation}
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestampDtsUs ↔ FutureOr<int?>
@brief Video encoding timestamp in microseconds
getter/setter pair
timestampUs ↔ FutureOr<int?>
@brief Video capture timestamp in microseconds
getter/setter pair
width ↔ FutureOr<int?>
@brief Video frame width in px
getter/setter pair

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter