ByteRTCExpressionDetectConfig class

Inheritance
  • Object
  • NativeClass
  • ByteRTCExpressionDetectConfig

Constructors

ByteRTCExpressionDetectConfig([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
enableAgeDetect ↔ FutureOr<BOOL?>
@brief Whether to enable age detection.
getter/setter pair
enableAttractivenessDetect ↔ FutureOr<BOOL?>
@brief Whether to enable attractiveness detection.
getter/setter pair
enableEmotionDetect ↔ FutureOr<BOOL?>
@brief Whether to enable emotion detection.
getter/setter pair
enableGenderDetect ↔ FutureOr<BOOL?>
@brief Whether to enable gender detection.
getter/setter pair
enableHappinessDetect ↔ FutureOr<BOOL?>
@brief Whether to enable happiness detection.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ready → Future<void>
Whether the instance is initialized
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter