ByteRTCFaceDetectionResult class

Inheritance
  • Object
  • NativeClass
  • ByteRTCFaceDetectionResult

Constructors

ByteRTCFaceDetectionResult([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
detectResult ↔ FutureOr<int?>
@brief Face Detection Result
- 0: Success - !0: Failure. See Error Code Table.
getter/setter pair
faces ↔ FutureOr<NSArray<ByteRTCRectangle>?>
@brief The face recognition rectangles. The length of the array is the same as the number of detected faces. See ByteRTCRectangle{@link #ByteRTCRectangle}.
getter/setter pair
frameTimestamp ↔ FutureOr<int?>
@brief The time stamp of the video frame using face detection.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageHeight ↔ FutureOr<int?>
@brief Height of the original image (px)
getter/setter pair
imageWidth ↔ FutureOr<int?>
@brief Width of the original image (px)
getter/setter pair
ready → Future<void>
Whether the instance is initialized
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter