ByteRTCMediaTypeEnhancementConfig class

Inheritance
  • Object
  • NativeClass
  • ByteRTCMediaTypeEnhancementConfig

Constructors

ByteRTCMediaTypeEnhancementConfig([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
enhanceAudio ↔ FutureOr<BOOL?>
@brief Apply to audio stream (Screen-sharing audio not included) or not. Not by default.
getter/setter pair
enhanceScreenAudio ↔ FutureOr<BOOL?>
@brief Apply to screen sharing audio or not. Not by default.
getter/setter pair
enhanceScreenVideo ↔ FutureOr<BOOL?>
@brief Apply to screen sharing video or not. Not by default.
getter/setter pair
enhanceSignaling ↔ FutureOr<BOOL?>
@brief Apply to signaling or not. Not by default.
getter/setter pair
enhanceVideo ↔ FutureOr<BOOL?>
@brief Apply to video (Screen-sharing video not included) or not. Not by default.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ready → Future<void>
Whether the instance is initialized
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter