ByteRTCMixedStreamConfig class

Inheritance
  • Object
  • NativeClass
  • ByteRTCMixedStreamConfig

Constructors

ByteRTCMixedStreamConfig([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
advancedConfig ↔ FutureOr<NSMutableDictionary?>
@hidden for internal use only @brief Custom parameter
getter/setter pair
audioConfig ↔ FutureOr<ByteRTCMixedStreamAudioConfig?>
@brief Audio mixed related configurations. See ByteRTCMixedStreamAudioConfig{@link #ByteRTCMixedStreamAudioConfig} for data types. It's recommended to be set.
- This parameters cannot be updated during the task. - This parameter is not supported for WTN stream tasks.
getter/setter pair
authInfo ↔ FutureOr<NSMutableDictionary?>
@hidden for internal use only @brief Authentication information passed through from the App
getter/setter pair
backgroundColor ↔ FutureOr<NSString?>
@brief Background-color of the mixed stream in hexadecimal values such as #FFFFFF and #000000. The default value is #000000 (black). It's recommended to be set.
With invalid or empty input, the configurations will be set as the default values.
getter/setter pair
backgroundImageURL ↔ FutureOr<NSString?>
@valid since 3.57 @brief Sets the URL of the background image for the canvas that renders the mixed stream, with a maximum length of 1024 bytes.
You can input images in the following supported formats: JPG, JPEG, PNG.
If the width and height of the background image are different from the screen dimensions, the background image will be scaled to fill the screen.
getter/setter pair
controlConfig ↔ FutureOr<ByteRTCMixedStreamControlConfig?>
@brief Server mix Control config. See ByteRTCMixedStreamControlConfig{@link #ByteRTCMixedStreamControlConfig} for detail.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
interpolationMode ↔ FutureOr<ByteRTCInterpolationMode?>
@brief Layout mode. See ByteRTCInterpolationMode{@link #ByteRTCInterpolationMode}. The optional values:
getter/setter pair
layoutMode ↔ FutureOr<ByteRTCStreamLayoutMode?>
@brief Layout mode. See ByteRTCStreamLayoutMode{@link #ByteRTCStreamLayoutMode}. The optional values:
- auto: Auto layout. The default value. - custom: Custom mode.
getter/setter pair
pushTargetType ↔ FutureOr<ByteRTCMixedStreamPushTargetType?>
@brief Layout mode. See ByteRTCMixedStreamPushTargetType{@link #ByteRTCMixedStreamPushTargetType}. The optional values:
getter/setter pair
pushURL ↔ FutureOr<NSString?>
@hidden for internal use only @brief The URL for live transcoding. Only supports live transcoding via RTMP. The URL should match the regular expression /^rtmps?:\\/\\//. It's recommended to be set.
- This parameters cannot be updated during the task. - This parameter is not supported for WTN stream tasks.
getter/setter pair
ready → Future<void>
Whether the instance is initialized
no setterinherited
regions ↔ FutureOr<NSArray<ByteRTCMixedStreamLayoutRegionConfig>?>
@brief List of user's video layout information. The specific layout of each stream is detailed in ByteRTCMixedStreamLayoutRegionConfig{@link #ByteRTCMixedStreamLayoutRegionConfig}. It's recommended to be set.
With invalid or empty input, the configurations will be set as the default values.
getter/setter pair
roomID ↔ FutureOr<NSString?>
@brief The room ID for live transcoding. The sum length of roomID and userID should not exceed 126 bytes. It's recommended to be set.
This parameter cannot be updated during the task.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spatialAudioConfig ↔ FutureOr<ByteRTCMixedStreamSpatialAudioConfig?>
@hidden(macOS) @brief The spatial audio config when pushing to CDN. See ByteRTCMixedStreamSpatialAudioConfig{@link #ByteRTCMixedStreamSpatialAudioConfig} for detail.
getter/setter pair
userConfigExtraInfo ↔ FutureOr<NSString?>
@brief Info passed through from the user.
This parameter is not supported for WTN stream tasks.
getter/setter pair
userID ↔ FutureOr<NSString?>
@brief The user ID for live transcoding. The sum length of roomID and userID should not exceed 126 bytes. It's recommended to be set.
This parameter cannot be updated during the task.
getter/setter pair
videoConfig ↔ FutureOr<ByteRTCMixedStreamVideoConfig?>
@brief Video transcoding related configurations. See ByteRTCMixedStreamVideoConfig{@link #ByteRTCMixedStreamVideoConfig}. It's recommended to be set.
getter/setter pair

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter

Static Methods

defaultMixedStreamConfig() → FutureOr<ByteRTCMixedStreamConfig>
@brief Gets the default configurations for pushing streams to CDN. @return Configurations for pushing streams to CDN. See ByteRTCMixedStreamConfig{@link #ByteRTCMixedStreamConfig}.