ByteRTCMixedStreamVideoConfig class

Inheritance
  • Object
  • NativeClass
  • ByteRTCMixedStreamVideoConfig

Constructors

ByteRTCMixedStreamVideoConfig([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
bitrate ↔ FutureOr<int?>
@brief The bitrate (Kbps) in range of 1, 10000. The default value is self-adaptive. It's recommended to be set.
getter/setter pair
enableBFrame ↔ FutureOr<BOOL?>
@brief Whether to push streams with B frame, only support by server mix.
getter/setter pair
fps ↔ FutureOr<int?>
@brief The frame rate (FPS) in range of 1, 60. The default value is 15 FPS. It's recommended to be set.
getter/setter pair
gop ↔ FutureOr<int?>
@brief The time interval between I-frames (second) in range of 1, 5. The default value is 2 seconds. It's recommended to be set.
These parameters cannot be updated during the task.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ FutureOr<int?>
@brief The height (pixels) to be set. The range is 2, 1920, and must be an even number. The default value is 360 pixels. It's recommended to be set.
If an odd number is set, the height will be adjusted to the next larger even number.
getter/setter pair
ready → Future<void>
Whether the instance is initialized
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
videoCodec ↔ FutureOr<ByteRTCMixedStreamVideoCodecType?>
@brief The video codec. See ByteRTCMixedStreamVideoCodecType{@link #ByteRTCMixedStreamVideoCodecType}. The default value is 0. It's recommended to be set.
These parameters cannot be updated during the task.
getter/setter pair
width ↔ FutureOr<int?>
@brief The width (pixels) to be set. The range is 2, 1920, and must be an even number. The default value is 640 pixels. It's recommended to be set.
If an odd number is set, the width will be adjusted to the next larger even number.
getter/setter pair

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter