ByteRTCRemoteAudioStats class

Inheritance
  • Object
  • NativeClass
  • ByteRTCRemoteAudioStats

Constructors

ByteRTCRemoteAudioStats([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
audioLossRate ↔ FutureOr<float?>
@brief Audio packet loss rate. The audio downlink packet loss rate in the reference period, the value range is 0,1.
getter/setter pair
concealedSamples ↔ FutureOr<int?>
@brief Audio PLC Total number of sample points.
getter/setter pair
concealmentEvent ↔ FutureOr<int?>
@brief PLC cumulative times.
getter/setter pair
decDuration ↔ FutureOr<int?>
@brief Cumulative decoding time in seconds of the remote audio stream in this subscription.
getter/setter pair
decodeFrameRate ↔ FutureOr<float?>
@brief Audio decode frame rate.
getter/setter pair
decSampleRate ↔ FutureOr<int?>
@brief Audio decoding sample rate. Audio decoding sample rate information in the reference period in Hz.
getter/setter pair
e2eDelay ↔ FutureOr<int?>
@brief End-to-end latency at the user experience level. The delay from the completion of encoding at the transmitting end to the completion of decoding at the receiving end, in units of ms.
getter/setter pair
frozenRate ↔ FutureOr<int?>
@brief The accumulated length of the audio card occurs after the remote user joins the room as a percentage of the total effective length of the audio. The effective duration of audio refers to the duration of audio other than stopping sending audio streams and disabling audio modules after remote users enter the room to publish audio streams.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jitter ↔ FutureOr<int?>
@brief Video downlink network jitter in ms.
getter/setter pair
jitterBufferDelay ↔ FutureOr<int?>
@brief The delay caused by the introduction of the jitter buffer mechanism. The unit is ms.
getter/setter pair
numChannels ↔ FutureOr<int?>
@brief Number of audio channels.
getter/setter pair
playoutSampleRate ↔ FutureOr<int?>
@brief Play sample rate. Audio playback sample rate information within the reference period in Hz.
getter/setter pair
quality ↔ FutureOr<int?>
@brief The quality of the audio stream sent by the remote user. Value meaning reference ByteRTCNetworkQuality{@link #ByteRTCNetworkQuality}.
getter/setter pair
ready → Future<void>
Whether the instance is initialized
no setterinherited
receivedKBitrate ↔ FutureOr<float?>
@brief Receiving bit rate. The audio reception rate in the reference period in kbps.
getter/setter pair
receivedSampleRate ↔ FutureOr<int?>
@brief Audio reception sampling rate. Remote audio sample rate information received within the reference period, in Hz.
getter/setter pair
rtt ↔ FutureOr<int?>
@brief Round-trip time for client side to server level data transfer in ms.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stallCount ↔ FutureOr<int?>
@brief Number of audio cards. Number of cards in the reference period.
getter/setter pair
stallDuration ↔ FutureOr<int?>
@brief Audio Catton Duration. Catton duration in the reference period in ms.
getter/setter pair
statsInterval ↔ FutureOr<int?>
@brief Statistical interval. The interval of this reference period is in ms.
getter/setter pair
totalRtt ↔ FutureOr<int?>
@brief The sender-server level-the receiver-link data transmission round-trip time. The unit is ms.
getter/setter pair

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter