ByteRTCRemoteStreamStats class

Inheritance
  • Object
  • NativeClass
  • ByteRTCRemoteStreamStats

Constructors

ByteRTCRemoteStreamStats([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
audioStats ↔ FutureOr<ByteRTCRemoteAudioStats?>
@brief For statistics on remote audio streams. See ByteRTCRemoteAudioStats{@link #ByteRTCRemoteAudioStats}
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isScreen ↔ FutureOr<BOOL?>
@brief Whether the media stream belongs to the user is a screen stream. You can know whether the current statistics come from mainstream or screen stream.
getter/setter pair
ready → Future<void>
Whether the instance is initialized
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
rxQuality ↔ FutureOr<ByteRTCNetworkQuality?>
@brief The downlink network quality of the media stream belongs to the user. See ByteRTCNetworkQuality{@link #ByteRTCNetworkQuality} @deprecated since 3.45 and will be deleted in 3.51, use rtcRoom:onNetworkQuality:remoteQualities:{@link #ByteRTCRoomDelegate#rtcRoom:onNetworkQuality:remoteQualities} instead
getter/setter pair
txQuality ↔ FutureOr<ByteRTCNetworkQuality?>
@hidden @brief For the uplink network quality of the media stream of the user you belong to. See ByteRTCNetworkQuality{@link #ByteRTCNetworkQuality} @deprecated since 3.45 and will be deleted in 3.51, use rtcRoom:onNetworkQuality:remoteQualities:{@link #ByteRTCRoomDelegate#rtcRoom:onNetworkQuality:remoteQualities} instead
getter/setter pair
uid ↔ FutureOr<NSString?>
@brief User ID. The user ID of the audio source.
getter/setter pair
videoStats ↔ FutureOr<ByteRTCRemoteVideoStats?>
@brief For statistics on remote video streams. See ByteRTCRemoteVideoStats{@link #ByteRTCRemoteVideoStats}
getter/setter pair

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter