ByteRTCRemoteStreamSwitchEvent class
- Inheritance
-
- Object
- NativeClass
- ByteRTCRemoteStreamSwitchEvent
Properties
-
$resource
→ NativeResource
-
no setterinherited
-
afterVideoEnabled
↔ FutureOr<BOOL?>
-
@brief Whether a video stream after the stream switching
getter/setter pair
-
afterVideoIndex
↔ FutureOr<int?>
-
@brief The quality index of the subscribed stream after the stream switching
getter/setter pair
-
beforeVideoEnabled
↔ FutureOr<BOOL?>
-
@brief Whether a video stream before the stream switching
getter/setter pair
-
beforeVideoIndex
↔ FutureOr<int?>
-
@brief The quality index of the subscribed stream before the stream switching
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
isScreen
↔ FutureOr<BOOL?>
-
@brief Whether it is a screen-sharing stream
getter/setter pair
-
ready
→ Future<void>
-
Whether the instance is initialized
no setterinherited
-
reason
↔ FutureOr<ByteRTCFallbackOrRecoverReason?>
-
@brief Refer to ByteRTCFallbackOrRecoverReason{@link #ByteRTCFallbackOrRecoverReason} for the reason of the Fallback or reverting from the Fallback of the subscribed stream.
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
uid
↔ FutureOr<NSString?>
-
@brief User ID of the publisher of the subscribed media stream
getter/setter pair