ByteRTCRemoteVideoStats class

Inheritance
  • Object
  • NativeClass
  • ByteRTCRemoteVideoStats

Constructors

ByteRTCRemoteVideoStats([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
avSyncDiffMs ↔ FutureOr<int?>
@brief Audio/video synchronization diff in ms.
getter/setter pair
capToRenderDelay ↔ FutureOr<int?>
@brief End-to-end latency at the user experience level. The delay from the start of capturing at the sending end to the completion of rendering at the receiving end, in units of ms.
getter/setter pair
codecElapsePerFrame ↔ FutureOr<int?>
@brief Average time spent on video decoding in ms.
getter/setter pair
codecType ↔ FutureOr<ByteRTCVideoCodecType?>
@brief For the encoding type of the video, please refer to ByteRTCVideoCodecType{@link #ByteRTCVideoCodecType}.
getter/setter pair
decoderOutputFrameRate ↔ FutureOr<int?>
@brief Remote video decoding output frame rate.
getter/setter pair
e2eDelay ↔ FutureOr<int?>
@brief End-to-end latency at the user experience level. The delay from the completion of encoding at the transmitting end to the completion of decoding at the receiving end, in units of ms.
getter/setter pair
frozenRate ↔ FutureOr<int?>
@brief The cumulative duration of the video card of the remote user accounts for the percentage (%) of the total effective duration of the video after entering the room. The effective duration of the video refers to the duration of the video other than stopping sending the video stream and disabling the video module after the remote user enters the room to publish the video stream.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ FutureOr<int?>
@brief Remote video height.
getter/setter pair
isScreen ↔ FutureOr<BOOL?>
@brief Whether the remote video stream is a screen share stream. You can know whether the current data comes from mainstream or screen stream.
getter/setter pair
jitter ↔ FutureOr<int?>
@brief Video downlink network jitter in ms.
getter/setter pair
ready → Future<void>
Whether the instance is initialized
no setterinherited
receivedFrameRate ↔ FutureOr<int?>
@brief Remote video receiving frame rate.
getter/setter pair
receivedKBitrate ↔ FutureOr<float?>
@brief Receiving bit rate. Video reception rate within the reference period, in kbps.
getter/setter pair
renderOutputFrameRate ↔ FutureOr<int?>
@brief Remote video rendering output frame rate.
getter/setter pair
rtt ↔ FutureOr<int?>
@brief Round-trip time. The unit is ms.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stallCount ↔ FutureOr<int?>
@brief The number of remote video cards.
getter/setter pair
stallDuration ↔ FutureOr<int?>
@brief Distal video lag duration, in ms.
getter/setter pair
statsInterval ↔ FutureOr<int?>
@brief Statistical interval, the interval of this reference period, in ms.
This field is used to set the reference period for the callback, currently set to 2s.
getter/setter pair
superResolutionMode ↔ FutureOr<ByteRTCVideoSuperResolutionMode?>
@hidden for internal use only @brief Super-resolution mode. See ByteRTCVideoSuperResolutionMode{@link #ByteRTCVideoSuperResolutionMode}.
getter/setter pair
videoIndex ↔ FutureOr<int?>
@brief The resolution subscript of the SDK subscribed remote video stream.
getter/setter pair
videoLossRate ↔ FutureOr<float?>
@brief Remote video packet loss rate. The video downlink packet loss rate in the reference period, the value range is 0,1.
getter/setter pair
width ↔ FutureOr<int?>
@brief Distal video width.
getter/setter pair

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter