ByteRTCRoomStats class

Inheritance
  • Object
  • NativeClass
  • ByteRTCRoomStats

Constructors

ByteRTCRoomStats([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
duration ↔ FutureOr<int?>
@brief The duration, in seconds, that the local user has spent in the room.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ready → Future<void>
Whether the instance is initialized
no setterinherited
rtt ↔ FutureOr<int?>
@brief Client side round-trip time
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
rxAudioKBitrate ↔ FutureOr<int?>
@brief Local user's audio receiving bit rate (kbps), instantaneous value
getter/setter pair
rxBytes ↔ FutureOr<int?>
@brief The total number of bytes received by the local user (bytes), the cumulative value
getter/setter pair
rxCellularKBitrate ↔ FutureOr<int?>
@brief Cellular Link Receive bit rate (kbps), get the instantaneous value of the data
getter/setter pair
rxJitter ↔ FutureOr<int?>
@hidden currently not available @brief The system downlink network jitter(ms)
getter/setter pair
rxKbitrate ↔ FutureOr<int?>
@brief The instantaneous value of Rx bitrate in kbps
getter/setter pair
rxLostrate ↔ FutureOr<float?>
@brief App Current downlink packet loss rate
getter/setter pair
rxScreenKBitrate ↔ FutureOr<int?>
@brief The instantaneous TX bitrate of screen-sharing video in Kbps
getter/setter pair
rxVideoKBitrate ↔ FutureOr<int?>
@brief Local user's video receiving bit rate (kbps), instantaneous value
getter/setter pair
txAudioKBitrate ↔ FutureOr<int?>
@brief Local user's audio transmission bit rate (kbps), instantaneous value
getter/setter pair
txBytes ↔ FutureOr<int?>
@brief The total number of bytes sent by the local user (bytes), the cumulative value
getter/setter pair
txCellularKBitrate ↔ FutureOr<int?>
@brief Cellular Link Send bit rate (kbps), get the instantaneous value of the data
getter/setter pair
txJitter ↔ FutureOr<int?>
@hidden currently not available @brief The system downlink network jitter(ms)
getter/setter pair
txKbitrate ↔ FutureOr<int?>
@brief The instantaneous value of Tx bitrate in kbps
getter/setter pair
txLostrate ↔ FutureOr<float?>
@brief App current uplink packet loss rate
getter/setter pair
txScreenKBitrate ↔ FutureOr<int?>
@brief The instantaneous RX bitrate of screen-sharing video in Kbps
getter/setter pair
txVideoKBitrate ↔ FutureOr<int?>
@brief Local user's video transmission bit rate (kbps), instantaneous value
getter/setter pair
userCount ↔ FutureOr<int?>
@brief Number of visible users in the current room, including local users themselves
getter/setter pair

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter