ByteRTCStream class

Inheritance
  • Object
  • NativeClass
  • ByteRTCStream

Constructors

ByteRTCStream([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
hasAudio ↔ FutureOr<BOOL?>
@brief Whether the stream includes an audio stream.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasVideo ↔ FutureOr<BOOL?>
@brief Whether this stream includes a video stream.
getter/setter pair
isScreen ↔ FutureOr<BOOL?>
@brief Whether this stream is a shared screen stream.
getter/setter pair
maxVideoStreamDescription ↔ FutureOr<ByteRTCVideoSolution?>
@brief The maximum resolution of the video stream, the maximum publish resolution that can be supported by the callback publisher when multi-resolution publish subscription is enabled.
getter/setter pair
ready → Future<void>
Whether the instance is initialized
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamIndex ↔ FutureOr<ByteRTCStreamIndex?>
getter/setter pair
userId ↔ FutureOr<NSString?>
@brief The user ID that published this stream.
getter/setter pair
videoStreamDescriptions ↔ FutureOr<NSArray<ByteRTCVideoSolution>?>
@brief Resolution information of the video stream.
When a remote user calls setVideoEncoderConfig:{@link #ByteRTCEngine#setVideoEncoderConfig} method to publish multiple configured video streams, this will contain attribute information for all video streams published by the user.
See ByteRTCVideoSolution{@link #ByteRTCVideoSolution}.
getter/setter pair

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter