ByteRTCSubscribeVideoConfig class

Inheritance
  • Object
  • NativeClass
  • ByteRTCSubscribeVideoConfig

Constructors

ByteRTCSubscribeVideoConfig([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
priority ↔ FutureOr<int?>
@brief Remote user priority. See ByteRTCRemoteUserPriority{@link #ByteRTCRemoteUserPriority}, the default value is 0.
getter/setter pair
ready → Future<void>
Whether the instance is initialized
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
videoIndex ↔ FutureOr<int?>
@brief Subscribed video stream resolution subscript.
Quality level of the video stream subscribed to.
In Simulcast mode, use a number to specify the expected quality of the video stream to be subscribed to. In Simulcast mode, a video has a diversity of encoded qualities that ranking from 0 to 3. Call setLocalSimulcastMode:{@link #ByteRTCEngine#setlocalsimulcastmode} to enable Simulcast mode on the publisher's clients.
Ranging from -1 to 3
0 (Default): The best quality
-1: Use the previous settings.
getter/setter pair

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter