ByteRtcScreenCapturerExt class
- Inheritance
-
- Object
- NativeClass
- ByteRtcScreenCapturerExt
Constructors
- ByteRtcScreenCapturerExt([NativeClassOptions? options])
Properties
- $resource → NativeResource
-
no setterinherited
-
delegate
↔ FutureOr<
NSObject< ByteRtcScreenCapturerExtDelegate> ?> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ready
→ Future<
void> -
Whether the instance is initialized
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
getter/setter pair
Methods
-
destroy(
) → void -
inherited
-
nativeCall<
T> (String method, [List? args, NativeMethodMeta? meta]) → Future< T> -
Call instance method
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
processSampleBuffer(
CMSampleBufferRef sampleBuffer, RPSampleBufferType sampleBufferType) → FutureOr< void> - @detail api @brief Push data captured by Extension @param sampleBuffer Captured data @param sampleBufferType Data type
-
sendInstanceGet<
T> (String property) → Future< T> -
Get instance property
inherited
-
sendInstancePropertiesGet(
dynamic nativeClass) → Future< Map< String, dynamic> > -
Get instance properties
inherited
-
sendInstanceSet(
String property, dynamic value) → Future< void> -
Set instance property
inherited
-
startWithDelegate(
NSObject< ByteRtcScreenCapturerExtDelegate> delegate, NSString groupId) → FutureOr<void> -
@detail api
@brief Start screen capture
After the Extension is started, the system will automatically call this method to enable screen capture. @param delegate Callback agent, see ByteRtcScreenCapturerExtDelegate{@link #ByteRtcScreenCapturerExtDelegate} @param groupId The group ID set in App groups -
stop(
) → FutureOr< void> -
@detail api
@brief Stop screen capture
After the Extension is closed, the system will automatically call this method to stop screen capture. -
toString(
) → String -
A string representation of this object.
inherited
-
updateResource(
NativeResource resource) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- codegen_$namespace → dynamic
-
no setter