IAudioFrameObserver class

Constructors

IAudioFrameObserver({FutureOr<void> onRecordAudioFrame(AudioFrame audioFrame)?, FutureOr<void> onPlaybackAudioFrame(AudioFrame audioFrame)?, FutureOr<void> onRemoteUserAudioFrame(String streamId, AudioFrame audioFrame)?, FutureOr<void> onMixedAudioFrame(AudioFrame audioFrame)?, FutureOr<void> onCaptureMixedAudioFrame(AudioFrame audioFrame)?})

Properties

hashCode → int
The hash code for this object.
no setterinherited
onCaptureMixedAudioFrame ↔ FutureOr<void> Function(AudioFrame audioFrame)?
@detail callback @brief Return the mixed audio data of the data recorded by local microphone and the audio data of MediaPlayer and EffectPlayer. @param audioFrame Audio data. See IAudioFrame{@link #IAudioFrame}.
getter/setter pair
onMixedAudioFrame ↔ FutureOr<void> Function(AudioFrame audioFrame)?
@detail callback @author wangjunzheng @brief Returns the mixed audio data including the data recorded by local microphone and that of all remote users subscribed by the local user. @param audioFrame Audio data. See IAudioFrame{@link #IAudioFrame}.
getter/setter pair
onPlaybackAudioFrame ↔ FutureOr<void> Function(AudioFrame audioFrame)?
@detail callback @author wangjunzheng @brief Returns the mixed audio data of all remote users subscribed by the local user. @param audioFrame Audio data. See IAudioFrame{@link #IAudioFrame}.
getter/setter pair
onRecordAudioFrame ↔ FutureOr<void> Function(AudioFrame audioFrame)?
@detail callback @author wangjunzheng @brief Returns the audio data recorded by local microphone. @param audioFrame Audio data. See IAudioFrame{@link #IAudioFrame}.
getter/setter pair
onRemoteUserAudioFrame ↔ FutureOr<void> Function(String streamId, AudioFrame audioFrame)?
@detail callback @author wangjunzheng @brief Returns the audio data of one remote user. @param streamId Remote stream ID. @param streamInfo Remote stream information. See StreamInfo{@link #StreamInfo}. @param audioFrame Audio data. See IAudioFrame{@link #IAudioFrame}. @note This callback works on the playback thread. Don't do anything time-consuming in this callback, or it may affect the entire audio playback chain.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited