VideoFrameData class

Inheritance
  • Object
  • PackClass
  • VideoFrameData

Constructors

VideoFrameData({required VideoBufferType bufferType, required VideoPixelFormat pixelFormat, required VideoContentType contentType, required int timestampUs, required int width, required int height, required VideoRotation rotation, required int numberOfPlanes, required List<ByteBuffer> planeData, required Uint8List seiData, required Uint8List roiData, CVPixelBufferRef cvpixelbuffer, CameraId? cameraId, int? planeStrideArray, bool? $disableInit})
VideoFrameData.fromMap(Map<String, dynamic> map)
factory

Properties

$instance → dynamic
no setterinherited
bufferType ↔ VideoBufferType
@brief Video frame buffer type, see VideoBufferType{@link #VideoBufferType}. Required.
getter/setter pair
cameraId ↔ CameraId?
@platform ios @brief Camera position info of the video frame, see ByteRTCCameraID{@link #ByteRTCCameraID}
getter/setter pair
contentType ↔ VideoContentType
@brief Video content type. See VideoContentType{@link #VideoContentType}.
getter/setter pair
cvpixelbuffer ↔ dynamic
@platform ios @brief Data of CVPixelBufferRef type. Required, when format is kPixelFormatCVPixelBuffer
getter/setter pair
eglContext ↔ dynamic
@platform android @brief EGLContext
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
@brief Video frame height. Required.
getter/setter pair
numberOfPlanes ↔ int
@brief The number of video frame plane. Required, when bufferType is RAW_MEMORY.
getter/setter pair
pixelFormat ↔ VideoPixelFormat
@brief Video frame pixel format, see VideoPixelFormat{@link #VideoPixelFormat}. Required, when bufferType is RAW_MEMORY or GL_TEXTURE.
getter/setter pair
planeData ↔ List<ByteBuffer>
@brief Array of video frame plane. Required, when bufferType is RAW_MEMORY.
getter/setter pair
planeStride ↔ List<int>?
@platform android @brief Array of stride. Stride is the length of memory between two lines of image data in video frame plane in bytes. Required, when bufferType is RAW_MEMORY.
getter/setter pair
planeStrideArray ↔ int?
@platform ios @brief Array of stride. Stride is the length of memory between two lines of image data in video frame plane in bytes. Required, when bufferType is ByteRTCVideoBufferTypeRawMemory and ByteRTCVideoBufferTypeGLTexture.
getter/setter pair
roiData ↔ ArrayBuffer
@brief ROI(Region of Interest) Data in a video frame
getter/setter pair
rotation ↔ VideoRotation
@brief Video frame rotation angle
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seiData ↔ ArrayBuffer
@brief SEI data
getter/setter pair
textureId ↔ int?
@platform android @brief Texture ID. Required, when bufferType is RAW_MEMORY or GL_TEXTURE.
getter/setter pair
textureMatrix ↔ List<float>?
@platform android @brief Texture matrix
getter/setter pair
timestampUs ↔ int
@brief Video frame timestamp in microseconds. Required.
getter/setter pair
width ↔ int
@brief Video frame width. Required.
getter/setter pair

Methods

$createInstance(List args) → dynamic
Factory method for creating instances
override
$destroy() → void
inherited
$init(List args) → void
inherited
findOverrideIndices(List args, List<List<int>> indicesList) → List<int>
查找重载参数下标列表 @desc android 构造函数存在重载 此方法通过实际传入参数与构造函数参数列表集合的比对,来获取当前实际的需要使用的参数列表
inherited
fn2AndroidClass(Function callback, dynamic nativeClass(), String methodName) → dynamic
与 ts runtime 中的 fn2AndroidClass 功能一致 将 Dart 函数转换为 Android 回调类实例供 Android 侧使用
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
transformToPlatformConstructorArgs(List args, List<int> indices, Map<String, dynamic> typeMap, Map<String, dynamic> enumMap, Map<String, dynamic> classMap, String platformVar) → List
实例化参数处理 将 pack 过后的 enum / class 转成 android / ios 平台侧的 enum / class
inherited
updateInstance(dynamic instance) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

deepPackedMapValues(Map<String, dynamic> map) → dynamic
mapMemberToConstructorParams(Map json) → Map<String, dynamic>