ByteRTCScreenCaptureParam class

Inheritance
  • Object
  • NativeClass
  • ByteRTCScreenCaptureParam

Constructors

ByteRTCScreenCaptureParam([NativeClassOptions? options])

Properties

$resource → NativeResource
no setterinherited
bitrate ↔ FutureOr<int?>
@brief Screen capture bitrate rate in kbps
getter/setter pair
excludedWindowList ↔ FutureOr<NSArray<NSNumber>?>
@brief The list of excluded windows.
getter/setter pair
frameRate ↔ FutureOr<int?>
@brief Screen capture frame rate in fps
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ FutureOr<int?>
@brief The maximum height of the captured screen, measured in pixel.
getter/setter pair
highlightConfig ↔ FutureOr<ByteRTCHighlightConfig?>
@brief Settings for highlighting borders of the sharing region. See ByteRTCHighlightConfig{@link #ByteRTCHighlightConfig}.
getter/setter pair
minBitrate ↔ FutureOr<int?>
@brief Minimum video encoding bitrate in kbps. The encoding bitrate will not be lower than the minBitrate.
It defaults to 0.
It ranges within [0, bitrate). When bitrate < minBitrate, the bitrate is self-adpapted.
In the following circumstance, the assignment to this variable has no effect:
- When bitrate = 0, the video encoding is disabled. - When bitrate < 0, the bitrate is self-adapted.
getter/setter pair
mouseCursorCaptureState ↔ FutureOr<ByteRTCMouseCursorCaptureState?>
@brief Whether to capture the mouse
getter/setter pair
ready → Future<void>
Whether the instance is initialized
no setterinherited
regionRect ↔ FutureOr<ByteRTCView>
@brief Screen capture area.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ FutureOr<int?>
@brief The maximum width of the captured screen, measured in pixel.
getter/setter pair

Methods

destroy() → void
inherited
nativeCall<T>(String method, [List? args, NativeMethodMeta? meta]) → Future<T>
Call instance method
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendInstanceGet<T>(String property) → Future<T>
Get instance property
inherited
sendInstancePropertiesGet(dynamic nativeClass) → Future<Map<String, dynamic>>
Get instance properties
inherited
sendInstanceSet(String property, dynamic value) → Future<void>
Set instance property
inherited
toString() → String
A string representation of this object.
inherited
updateResource(NativeResource resource) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

codegen_$namespace → dynamic
no setter